@@ -2,9 +2,17 @@ from predicthq.endpoints.base import BaseEndpoint
 from predicthq.endpoints.decorators import accepts, returns
 from .decorators import preload_config_defaults
 from .schemas import AccessToken
+from deprecated import deprecated
 
 
 class OAuth2Endpoint(BaseEndpoint):
+    @deprecated(
+        reason=(
+            "OAuth2 endpoints in the SDK are deprecated and will be removed in future releases. "
+            "Use TokenAuth (API Access Token) with Client(..., access_token=...)."
+        ),
+        category=FutureWarning,
+    )
     @accepts()
     @preload_config_defaults(["client_id", "client_secret", "scope", "grant_type"])
     @returns(AccessToken)
@@ -22,6 +30,13 @@ class OAuth2Endpoint(BaseEndpoint):
             verify=verify_ssl,
         )
 
+    @deprecated(
+        reason=(
+            "OAuth2 endpoints in the SDK are deprecated and will be removed in future releases. "
+            "Use TokenAuth (API Access Token) with Client(..., access_token=...)."
+        ),
+        category=FutureWarning,
+    )
     @accepts()
     @preload_config_defaults(["client_id", "client_secret", "token_type_hint"])
     def revoke_token(self, client_id, client_secret, token, token_type_hint, **kwargs):
