@@ -19,9 +19,7 @@ class FeaturesEndpoint(UserBaseEndpoint):
     def mutate_bool_to_default_for_type(cls, user_request_spec):
         for key, val in user_request_spec.items():
             if any(key.startswith(x) for x in cls.FIELDS_TO_MUTATE):
-                user_request_spec[key] = [
-                    cls.BASE_FEATURE_CRITERIA if isinstance(v, bool) else v for v in val
-                ]
+                user_request_spec[key] = [cls.BASE_FEATURE_CRITERIA if isinstance(v, bool) else v for v in val]
 
     @accepts(query_string=False)
     @returns(FeatureResultSet)
